# TERminal GRaph drAWing
A dumb and simple graph printing in your terminal, implemented in Python.

Here is the API:

    GRAPH = {'a': {'b', 'c'}, 'd': {'b', 'e'}, 'f': {'g'}}

    print('\n'.join(tergraw.pretty_view(GRAPH, oriented=True)))

Installation:

    pip install tergraw
    
Needs the [graphviz library](http://graphviz.org/Download..php) to be installed.

links: tergraw on [github](http://github.com/aluriak/tergraw) and [pypi](http://pypi.python.org/pypi/tergraw)
